@@ -90,13 +90,22 @@ class MrHat:
                 return out
         return "MC_%s-001" % version
     
+    def migrate_all_to_git_for_project(self, module):
+        for job in self.get_jobs_for_cvs_repo(module):
+            print("Migrate CVS job: {}".format(job))
+            self.move_to_git(job)
+            
+        for job in self.get_jobs_for_git_module(module):
+            print("Update Git job Config: {}".format(job))
+            self.move_to_git(job)
+    
     def get_git_repo_map(self):
         try:
             mapfile = open('git_jobmap.data', 'rb')
             jobmap = pickle.load(mapfile)
             mapfile.close()
         except:
-            print "Creating Repo Map"
+            print("Creating Repo Map")
             jobmap = self.create_git_repo_map()
             
         return jobmap
@@ -130,7 +139,7 @@ class MrHat:
             jobmap = pickle.load(mapfile)
             mapfile.close()
         except:
-            print "Creating Repo Map"
+            print("Creating Repo Map")
             jobmap = self.create_repo_map()
             
         return jobmap
@@ -175,10 +184,37 @@ class MrHat:
                 out.append(job)
         return out
     
+    def remove_git_tagging(self, job):
+        config = Config(self.jenkins[job].get_config())
+        config.remove_git_publisher()
+        out = config.remove_version_builder()
+        self.jenkins[job].update_config(out)
+    
     def move_to_git(self, job):
         config = Config(self.jenkins[job].get_config())
-        gitconfig = config.create_git_config()
-        self.jenkins[job].update_config(gitconfig)
+        if not config.is_configured_for_git():
+            print("Migrating SCM configuration for job {} to Git".format(job))
+            gitconfig = config.create_git_config()
+            self.jenkins[job].update_config(gitconfig)
+
+            if job.startswith("ci"):
+                print("Adding version number builder to build wrappers")
+                version = config.set_version_builder()
+                self.jenkins[job].update_config(version)
+         
+                print("Configuring Tag Publisher")
+                publish = config.set_git_publisher()
+                self.jenkins[job].update_config(publish)
+            else:
+                print("Removing Git Tag Publisher")
+                nopublish = config.remove_git_publisher()
+                self.jenkins[job].update_config(nopublish)
+        
+            print("Ensuring Git remote name is set correctly (origin)")   
+            origin = config.set_git_remote_name('origin')
+            self.jenkins[job].update_config(origin)
+        else:
+            print("SCM is already configured for Git")
     
     def __increment__(self, build_num):
         '''
