@@ -4,16 +4,16 @@ Created on Jul 26, 2013
 @author: scrosby
 '''
 import unittest
-from ..jenkins import MrHatSession
+from ..jenkins import JenkinsSession
 
 
 class Test(unittest.TestCase):
 
 
     def test_mr_hat_session(self):
-        mrhat = MrHatSession(filename=".test_data")
+        mrhat = JenkinsSession(filename=".test_data")
         token = mrhat.login('scrosby', 'Ih@techangingpassw0rds')
-        print 'token: %s' % token
+        print('token: {}'.format(token))
 
 
 if __name__ == "__main__":
